/*
 * System Interface Library for games
 * Copyright (c) 2007-2016 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/test/sysdep/opengl/internal.c: Internal helper routines for OpenGL
 * tests.
 */

#include "src/base.h"
#include "src/graphics.h"
#include "src/sysdep.h"
#include "src/sysdep/opengl/opengl.h"
#include "src/test/base.h"
#include "src/test/sysdep/opengl/internal.h"

/*************************************************************************/
/*************************************************************************/

int opengl_has_features_uninitted(unsigned int features)
{
    /* This wrapper code is taken from run_tests_in_window() and its helper
     * functions in test/graphics/internal.c. */
    int width = 64, height = 64;
    ASSERT(graphics_init());
    if (!graphics_set_display_attr("window", 1)) {
        /* Look for the smallest usable display size and use that instead. */
        const GraphicsDisplayModeList *mode_list;
        ASSERT(mode_list = graphics_list_display_modes(0));
        ASSERT(mode_list->num_modes > 0);
        int i;
        for (i = 0; i < mode_list->num_modes; i++) {
            if (mode_list->modes[i].width >= width
             && mode_list->modes[i].height >= height) {
                break;
            }
        }
        if (i >= mode_list->num_modes) {
            FAIL("No available display mode of size at least %dx%d",
                 width, height);
        }
        width = mode_list->modes[i].width;
        height = mode_list->modes[i].height;
    }
    ASSERT(graphics_set_display_mode(width, height, NULL));

    const int result = opengl_has_features(features);

    graphics_cleanup();
    return result;
}

/*************************************************************************/
/*************************************************************************/

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
